==> qgis_0.3.0.orig.tar.gz: qgis-0.3.0/src/qgssimarenderer.h <==
/***************************************************************************
                          qgssimarenderer.h 
 Single marker renderer
                             -------------------
    begin                : March 2004
    copyright            : (C) 2004 by Marco Hugentobler
    email                : mhugent@geo.unizh.ch
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 /* $Id: qgssimarenderer.h,v 1.10 2004/05/16 20:39:47 mhugent Exp $ */

#ifndef QGSSIMARENDERER_H
#define QGSSIMARENDERER_H

#include "qgsrenderer.h"
#include "qgsrenderitem.h"
#include "qgsmarkersymbol.h"

class QgsSiMaRenderer: public QgsRenderer
{
 public:
    QgsSiMaRenderer();
    ~QgsSiMaRenderer();
    /**Replaces the current mItem by ri*/
    void addItem(QgsRenderItem* ri);
    void initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLayerProperties* pr=0);
    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor);
    /**Reads the renderer configuration from an XML file
     @param rnode the DOM node to read 
     @param vl the vector layer which will be associated with the renderer*/
    virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
    /**Writes the contents of the renderer to a configuration file*/
    virtual void writeXML(std::ofstream& xml);
    bool needsAttributes();
    /**Returns an empty list, since no classification attributes are used*/
    virtual std::list<int> classificationAttributes();
    QgsRenderItem* item();
 protected:
    QgsRenderItem* mItem;
};

inline QgsSiMaRenderer::QgsSiMaRenderer()
{
    mItem=new QgsRenderItem(new QgsMarkerSymbol(),"","");
}

inline QgsSiMaRenderer::~QgsSiMaRenderer()
{
    delete mItem;
}

inline bool QgsSiMaRenderer::needsAttributes()
{
    return false;
}

inline void QgsSiMaRenderer::addItem(QgsRenderItem* ri)
{
    delete mItem;
    mItem=ri;
}

inline QgsRenderItem* QgsSiMaRenderer::item()
{
    return mItem;
}

#endif

==> qgis_0.6.0.orig.tar.gz: qgis-0.6.0/src/qgssimarenderer.h <==
/***************************************************************************
                               qgssimarenderer.h 
                             Single marker renderer
                             -------------------
    begin                : March 2004
    copyright            : (C) 2004 by Marco Hugentobler
    email                : mhugent@geo.unizh.ch
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
 /* $Id: qgssimarenderer.h,v 1.15 2004/10/26 17:28:03 mcoletti Exp $ */

#ifndef QGSSIMARENDERER_H
#define QGSSIMARENDERER_H

#include "qgsrenderer.h"
#include "qgsrenderitem.h"
#include "qgsmarkersymbol.h"

class QgsSiMaRenderer: public QgsRenderer
{
 public:
    QgsSiMaRenderer();
    virtual ~QgsSiMaRenderer();
    /**Replaces the current mItem by ri*/
    void addItem(QgsRenderItem* ri);
    void initializeSymbology(QgsVectorLayer* layer, QgsDlgVectorLayerProperties* pr=0);
    void renderFeature(QPainter* p, QgsFeature* f, QPicture* pic, double* scalefactor, bool selected);
    /**Reads the renderer configuration from an XML file
     @param rnode the DOM node to read 
     @param vl the vector layer which will be associated with the renderer*/
    virtual void readXML(const QDomNode& rnode, QgsVectorLayer& vl);
    /**Writes the contents of the renderer to a configuration file*/
    virtual void writeXML(std::ostream& xml);
    bool needsAttributes();
    /**Returns an empty list, since no classification attributes are used*/
    virtual std::list<int> classificationAttributes();
    QgsRenderItem* item();
    /**Returns the renderers name*/
    QString name();
 protected:
    QgsRenderItem* mItem;
};

inline QgsSiMaRenderer::QgsSiMaRenderer()
{
    mItem=new QgsRenderItem(new QgsMarkerSymbol(),"","");
}

inline QgsSiMaRenderer::~QgsSiMaRenderer()
{
    delete mItem;
}

inline bool QgsSiMaRenderer::needsAttributes()
{
    return false;
}

inline void QgsSiMaRenderer::addItem(QgsRenderItem* ri)
{
    delete mItem;
    mItem=ri;
}

inline QgsRenderItem* QgsSiMaRenderer::item()
{
    return mItem;
}

#endif
